#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2024-06-30
# File  : cisco_meraki_org_device_status_ps.py (WATO)

# 2024-06-30: created to shadow built-in file -> move rule from "Applications, Processes & Services" to "Hardware, BIOS"

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersHardware,
)
from cmk.gui.valuespec import (
    Dictionary,
    TextInput,
    MonitoringState,
)

#
# Cisco Meraki Power Supply -> now built-in in cmk 2.3
#
def _parameter_valuespec_cisco_meraki_device_status_ps():
    return Dictionary(
        title=_("Cisco Meraki Powersupply status"),
        optional_keys=True,
        elements=[
            ("state_not_powering",
             MonitoringState(
                 title=_('Monitoring state if power supply is not "powering"'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        title=lambda: _("Cisco Meraki Power supply"),
        check_group_name="cisco_meraki_device_status_ps",
        group=RulespecGroupCheckParametersHardware,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_device_status_ps,
        match_type="dict",
        item_spec=lambda: TextInput(
            title=_("Slot number"),
        ),
    )
)
